@@ -3,7 +3,7 @@
  */
 
 /*
- * Copyright (C) 1986, 1988, 1989, 1991-2019, 2021, 2022,
+ * Copyright (C) 1986, 1988, 1989, 1991-2019, 2021-2024,
  * the Free Software Foundation, Inc.
  *
  * This file is part of GAWK, the GNU implementation of the
@@ -296,6 +296,7 @@ static struct optypetab {
 	{ "Op_store_var", " = " },
 	{ "Op_store_sub", " = " },
 	{ "Op_store_field", " = " },
+	{ "Op_store_field_exp", " = " },
 	{ "Op_assign_times", " *= " },
 	{ "Op_assign_quotient", " /= " },
 	{ "Op_assign_mod", " %= " },
@@ -413,7 +414,7 @@ opcode2str(OPCODE op)
 	if (op >= Op_illegal && op < Op_final)
 		return optypes[(int) op].desc;
 	fatal(_("unknown opcode %d"), (int) op);
-	return NULL;
+	return "";	// keeps the compiler happy in some cases
 }
 
 /* op2str --- convert an opcode type to corresponding operator or keyword */
@@ -1154,6 +1155,7 @@ r_get_lhs(NODE *n, bool reference)
 	case Node_var_array:
 		fatal(_("attempt to use array `%s' in a scalar context"),
 				array_vname(n));
+		return NULL;	// silence compiler warnings
 	case Node_array_ref:
 		if (n->orig_array->type == Node_var_array)
 			fatal(_("attempt to use array `%s' in a scalar context"),
@@ -1315,8 +1317,11 @@ setup_frame(INSTRUCTION *pc)
 
 		/* $0 needs to be passed by value to a function */
 		if (m == fields_arr[0]) {
+			NODE *copy;
+
+			copy = dupnode(m);	// will be real copy
 			DEREF(m);
-			m = dupnode(m);
+			m = copy;
 		}
 
 		switch (m->type) {
@@ -1540,7 +1545,7 @@ cmp_scalars(scalar_cmp_t comparison_type)
 {
 	NODE *t1, *t2;
 	int di;
-	bool ret;
+	bool ret = false;
 
 	t2 = POP_SCALAR();
 	t1 = TOP();
@@ -1548,12 +1553,15 @@ cmp_scalars(scalar_cmp_t comparison_type)
 	t1 = elem_new_to_scalar(t1);
 	t2 = elem_new_to_scalar(t2);
 
+	t1 = fixtype(t1);
+	t2 = fixtype(t2);
+
 	if (t1->type == Node_var_array) {
 		DEREF(t2);
 		fatal(_("attempt to use array `%s' in a scalar context"), array_vname(t1));
 	}
 
-	if ((t1->flags & STRING) != 0 || (t2->flags & STRING) != 0) {
+	if ((t1->flags & (STRING|REGEX)) != 0 || (t2->flags & (STRING|REGEX)) != 0) {
 		bool use_strcmp = (comparison_type == SCALAR_EQ || comparison_type == SCALAR_NEQ);
 		di = cmp_nodes(t1, t2, use_strcmp);
 
@@ -1576,11 +1584,11 @@ cmp_scalars(scalar_cmp_t comparison_type)
 		case SCALAR_GE:
 			ret = (di >= 0);
 			break;
+		default:
+			cant_happen("invalid value %d in cmp_scalars", (int) comparison_type);
+			break;
 		}
 	} else {
-		fixtype(t1);
-		fixtype(t2);
-
 #ifdef HAVE_MPFR
 		if (do_mpfr)
 			ret = mpg_cmp_as_numbers(t1, t2, comparison_type);
@@ -1607,7 +1615,7 @@ cmp_doubles(const NODE *t1, const NODE *t2, scalar_cmp_t comparison_type)
 
 	bool t1_nan = isnan(t1->numbr);
 	bool t2_nan = isnan(t2->numbr);
-	int ret;
+	int ret = false;
 
 	if ((t1_nan || t2_nan) && comparison_type != SCALAR_NEQ)
 		return false;
@@ -1631,6 +1639,9 @@ cmp_doubles(const NODE *t1, const NODE *t2, scalar_cmp_t comparison_type)
 	case SCALAR_GE:
 		ret = (t1->numbr >= t2->numbr);
 		break;
+	default:
+		cant_happen("invalid value %d in cmp_doubles", (int) comparison_type);
+		break;
 	}
 
 	return ret;
